@@ -17,16 +17,16 @@
 
 import sys
 
+from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
 
-import nova.conf
 from nova import config
 from nova import objects
+from nova.openstack.common.report import guru_meditation_report as gmr
 from nova import service
 from nova import version
 
-CONF = nova.conf.CONF
+CONF = cfg.CONF
 
 
 def main():
