@@ -18,10 +18,11 @@
 
 import sys
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from nova import config
-from nova.openstack.common import log as logging
+from nova import objects
 from nova.openstack.common.report import guru_meditation_report as gmr
 from nova import service
 from nova import utils
@@ -33,8 +34,9 @@ CONF.import_opt('scheduler_topic', 'nova.scheduler.rpcapi')
 
 def main():
     config.parse_args(sys.argv)
-    logging.setup("nova")
+    logging.setup(CONF, "nova")
     utils.monkey_patch()
+    objects.register_all()
 
     gmr.TextGuruMeditation.setup_autorun(version)
 
