@@ -20,9 +20,13 @@
 #
 # It is hypothetically possible that a hyper-v continuous deployer exists who
 # will have a poor experience because of this code revert, if that deployer
-# is you, please contact the nova team at openstack-discuss@lists.openstack.org
+# is you, please contact the nova team at openstack-dev@lists.openstack.org
 # and we will walk you through the manual fix required for this problem.
 
 
 def upgrade(migrate_engine):
     pass
+
+
+def downgrade(migrate_engine):
+    pass
