@@ -22,9 +22,6 @@
    :platform: Unix
 """
 
-from nova import objects
+import eventlet
 
-# NOTE(comstud): Make sure we have all of the objects loaded. We do this
-# at module import time, because we may be using mock decorators in our
-# tests that run at import time.
-objects.register_all()
+eventlet.monkey_patch(os=False)
