@@ -13,17 +13,20 @@
 #    under the License.
 
 import mock
+from oslo_config import cfg
 from oslo_serialization import jsonutils
 
 from nova import test
 from nova.tests.unit.api.openstack import fakes
 
+CONF = cfg.CONF
+
 
 class PluginTest(test.NoDBTestCase):
 
     @mock.patch("nova.api.openstack.APIRouterV21.api_extension_namespace")
     def test_plugin_framework_index(self, mock_namespace):
-        mock_namespace.return_value = 'nova.api.v21.test_extensions'
+        mock_namespace.return_value = 'nova.api.v3.test_extensions'
 
         app = fakes.wsgi_app_v21(init_only='test-basic')
         req = fakes.HTTPRequest.blank('/v2/fake/test')
