@@ -22,8 +22,9 @@ from oslo_utils import timeutils
 import six
 import webob
 
-from nova.api.openstack.compute import server_metadata \
-        as server_metadata_v21
+from nova.api.openstack.compute.plugins.v3 import server_metadata \
+    as server_metadata_v21
+from nova.api.openstack.compute import server_metadata as server_metadata_v2
 from nova.compute import rpcapi as compute_rpcapi
 from nova.compute import vm_states
 import nova.db
@@ -118,13 +119,13 @@ class ServerMetaDataTestV21(test.TestCase):
 
     def setUp(self):
         super(ServerMetaDataTestV21, self).setUp()
-        fakes.stub_out_key_pair_funcs(self)
-        self.stub_out('nova.db.instance_get', return_server)
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      return_server_by_uuid)
+        fakes.stub_out_key_pair_funcs(self.stubs)
+        self.stubs.Set(nova.db, 'instance_get', return_server)
+        self.stubs.Set(nova.db, 'instance_get_by_uuid',
+                       return_server_by_uuid)
 
-        self.stub_out('nova.db.instance_metadata_get',
-                      return_server_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_get',
+                       return_server_metadata)
 
         self.stubs.Set(compute_rpcapi.ComputeAPI, 'change_instance_metadata',
                        fake_change_instance_metadata)
@@ -136,7 +137,7 @@ class ServerMetaDataTestV21(test.TestCase):
         self.url = '/fake/servers/%s/metadata' % self.uuid
 
     def _get_request(self, param_url=''):
-        return fakes.HTTPRequestV21.blank(self.url + param_url)
+        return fakes.HTTPRequestV3.blank(self.url + param_url)
 
     def test_index(self):
         req = self._get_request()
@@ -152,14 +153,14 @@ class ServerMetaDataTestV21(test.TestCase):
         self.assertEqual(expected, res_dict)
 
     def test_index_nonexistent_server(self):
-        self.stub_out('nova.db.instance_metadata_get',
+        self.stubs.Set(nova.db, 'instance_metadata_get',
                        return_server_nonexistent)
         req = self._get_request()
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.index, req, self.url)
 
     def test_index_no_data(self):
-        self.stub_out('nova.db.instance_metadata_get',
+        self.stubs.Set(nova.db, 'instance_metadata_get',
                        return_empty_server_metadata)
         req = self._get_request()
         res_dict = self.controller.index(req, self.uuid)
@@ -173,24 +174,24 @@ class ServerMetaDataTestV21(test.TestCase):
         self.assertEqual(expected, res_dict)
 
     def test_show_nonexistent_server(self):
-        self.stub_out('nova.db.instance_metadata_get',
-                      return_server_nonexistent)
+        self.stubs.Set(nova.db, 'instance_metadata_get',
+                       return_server_nonexistent)
         req = self._get_request('/key2')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show, req, self.uuid, 'key2')
 
     def test_show_meta_not_found(self):
-        self.stub_out('nova.db.instance_metadata_get',
-                      return_empty_server_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_get',
+                       return_empty_server_metadata)
         req = self._get_request('/key6')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show, req, self.uuid, 'key6')
 
     def test_delete(self):
-        self.stub_out('nova.db.instance_metadata_get',
-                      return_server_metadata)
-        self.stub_out('nova.db.instance_metadata_delete',
-                      delete_server_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_get',
+                       return_server_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_delete',
+                       delete_server_metadata)
         req = self._get_request('/key2')
         req.method = 'DELETE'
         res = self.controller.delete(req, self.uuid, 'key2')
@@ -198,16 +199,16 @@ class ServerMetaDataTestV21(test.TestCase):
         self.assertIsNone(res)
 
     def test_delete_nonexistent_server(self):
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      return_server_nonexistent)
+        self.stubs.Set(nova.db, 'instance_get_by_uuid',
+                       return_server_nonexistent)
         req = self._get_request('/key1')
         req.method = 'DELETE'
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.delete, req, self.uuid, 'key1')
 
     def test_delete_meta_not_found(self):
-        self.stub_out('nova.db.instance_metadata_get',
-                      return_empty_server_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_get',
+                       return_empty_server_metadata)
         req = self._get_request('/key6')
         req.method = 'DELETE'
         self.assertRaises(webob.exc.HTTPNotFound,
@@ -219,7 +220,7 @@ class ServerMetaDataTestV21(test.TestCase):
         req.method = 'POST'
         req.content_type = "application/json"
         body = {"metadata": {"key9": "value9"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         res_dict = self.controller.create(req, self.uuid, body=body)
 
         body['metadata'].update({
@@ -230,8 +231,8 @@ class ServerMetaDataTestV21(test.TestCase):
         self.assertEqual(body, res_dict)
 
     def test_create_empty_body(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request()
         req.method = 'POST'
         req.headers["content-type"] = "application/json"
@@ -240,36 +241,36 @@ class ServerMetaDataTestV21(test.TestCase):
                           self.controller.create, req, self.uuid, body=None)
 
     def test_create_item_empty_key(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"metadata": {"": "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
                           self.controller.create, req, self.uuid, body=body)
 
     def test_create_item_non_dict(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"metadata": None}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
                           self.controller.create, req, self.uuid, body=body)
 
     def test_create_item_key_too_long(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"metadata": {("a" * 260): "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex_large,
@@ -277,36 +278,36 @@ class ServerMetaDataTestV21(test.TestCase):
                           req, self.uuid, body=body)
 
     def test_create_malformed_container(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"meta": {}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
                           self.controller.create, req, self.uuid, body=body)
 
     def test_create_malformed_data(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         body = {"metadata": ['asdf']}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
                           self.controller.create, req, self.uuid, body=body)
 
     def test_create_nonexistent_server(self):
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      return_server_nonexistent)
+        self.stubs.Set(nova.db, 'instance_get_by_uuid',
+                       return_server_nonexistent)
         req = self._get_request()
         req.method = 'POST'
         body = {"metadata": {"key1": "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPNotFound,
@@ -323,7 +324,7 @@ class ServerMetaDataTestV21(test.TestCase):
                 'key29': 'newkey',
             }
         }
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         response = self.controller.update_all(req, self.uuid, body=expected)
         self.assertEqual(expected, response)
 
@@ -338,7 +339,7 @@ class ServerMetaDataTestV21(test.TestCase):
                 'key99': 'value99',
             },
         }
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         res_dict = self.controller.update_all(req, self.uuid, body=expected)
 
         self.assertEqual(expected, res_dict)
@@ -349,14 +350,14 @@ class ServerMetaDataTestV21(test.TestCase):
         req.method = 'PUT'
         req.content_type = "application/json"
         expected = {'metadata': {}}
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         res_dict = self.controller.update_all(req, self.uuid, body=expected)
 
         self.assertEqual(expected, res_dict)
 
     def test_update_all_empty_body_item(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url + '/key1')
         req.method = 'PUT'
         req.headers["content-type"] = "application/json"
@@ -366,12 +367,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=None)
 
     def test_update_all_with_non_dict_item(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url + '/bad')
         req.method = 'PUT'
         body = {"metadata": None}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -379,49 +380,49 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=body)
 
     def test_update_all_malformed_container(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request()
         req.method = 'PUT'
         req.content_type = "application/json"
         expected = {'meta': {}}
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
 
         self.assertRaises(self.validation_ex,
                           self.controller.update_all, req, self.uuid,
                           body=expected)
 
     def test_update_all_malformed_data(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request()
         req.method = 'PUT'
         req.content_type = "application/json"
         expected = {'metadata': ['asdf']}
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
 
         self.assertRaises(self.validation_ex,
                           self.controller.update_all, req, self.uuid,
                           body=expected)
 
     def test_update_all_nonexistent_server(self):
-        self.stub_out('nova.db.instance_get', return_server_nonexistent)
+        self.stubs.Set(nova.db, 'instance_get', return_server_nonexistent)
         req = self._get_request()
         req.method = 'PUT'
         req.content_type = "application/json"
         body = {'metadata': {'key10': 'value10'}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
 
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.update_all, req, '100', body=body)
 
     def test_update_all_non_dict(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request()
         req.method = 'PUT'
         body = {"metadata": None}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex, self.controller.update_all,
@@ -432,19 +433,19 @@ class ServerMetaDataTestV21(test.TestCase):
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
         res_dict = self.controller.update(req, self.uuid, 'key1', body=body)
         expected = {"meta": {'key1': 'value1'}}
         self.assertEqual(expected, res_dict)
 
     def test_update_item_nonexistent_server(self):
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      return_server_nonexistent)
+        self.stubs.Set(nova.db, 'instance_get_by_uuid',
+                       return_server_nonexistent)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPNotFound,
@@ -452,8 +453,8 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=body)
 
     def test_update_item_empty_body(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         req.headers["content-type"] = "application/json"
@@ -463,12 +464,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=None)
 
     def test_update_malformed_container(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url)
         req.method = 'PUT'
         expected = {'meta': {}}
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -476,12 +477,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=expected)
 
     def test_update_malformed_data(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url)
         req.method = 'PUT'
         expected = {'metadata': ['asdf']}
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -489,12 +490,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=expected)
 
     def test_update_item_empty_key(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"meta": {"": "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -502,12 +503,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=body)
 
     def test_update_item_key_too_long(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"meta": {("a" * 260): "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex_large,
@@ -515,12 +516,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           req, self.uuid, ("a" * 260), body=body)
 
     def test_update_item_value_too_long(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": ("a" * 260)}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex_large,
@@ -528,12 +529,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           req, self.uuid, "key1", body=body)
 
     def test_update_item_too_many_keys(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1", "key2": "value2"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -541,12 +542,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=body)
 
     def test_update_item_body_uri_mismatch(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/bad')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -554,12 +555,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=body)
 
     def test_update_item_non_dict(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request('/bad')
         req.method = 'PUT'
         body = {"meta": None}
-        req.body = jsonutils.dump_as_bytes(body)
+        req.body = jsonutils.dumps(body)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -567,12 +568,12 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=body)
 
     def test_update_empty_container(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = fakes.HTTPRequest.blank(self.url)
         req.method = 'PUT'
         expected = {'metadata': {}}
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(self.validation_ex,
@@ -580,107 +581,120 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=expected)
 
     def test_too_many_metadata_items_on_create(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         data = {"metadata": {}}
         for num in range(CONF.quota_metadata_items + 1):
             data['metadata']['key%i' % num] = "blah"
         req = self._get_request()
         req.method = 'POST'
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPForbidden,
                           self.controller.create, req, self.uuid, body=data)
 
     def test_invalid_metadata_items_on_create(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request()
         req.method = 'POST'
         req.headers["content-type"] = "application/json"
 
         # test for long key
         data = {"metadata": {"a" * 260: "value1"}}
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         self.assertRaises(self.validation_ex_large,
                           self.controller.create, req, self.uuid, body=data)
 
         # test for long value
         data = {"metadata": {"key": "v" * 260}}
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         self.assertRaises(self.validation_ex_large,
                           self.controller.create, req, self.uuid, body=data)
 
         # test for empty key.
         data = {"metadata": {"": "value1"}}
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         self.assertRaises(self.validation_ex,
                           self.controller.create, req, self.uuid, body=data)
 
     def test_too_many_metadata_items_on_update_item(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         data = {"metadata": {}}
         for num in range(CONF.quota_metadata_items + 1):
             data['metadata']['key%i' % num] = "blah"
         req = self._get_request()
         req.method = 'PUT'
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         req.headers["content-type"] = "application/json"
 
         self.assertRaises(webob.exc.HTTPForbidden, self.controller.update_all,
                           req, self.uuid, body=data)
 
     def test_invalid_metadata_items_on_update_item(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         data = {"metadata": {}}
         for num in range(CONF.quota_metadata_items + 1):
             data['metadata']['key%i' % num] = "blah"
         req = self._get_request()
         req.method = 'PUT'
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         req.headers["content-type"] = "application/json"
 
         # test for long key
         data = {"metadata": {"a" * 260: "value1"}}
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         self.assertRaises(self.validation_ex_large,
                           self.controller.update_all, req, self.uuid,
                           body=data)
 
         # test for long value
         data = {"metadata": {"key": "v" * 260}}
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         self.assertRaises(self.validation_ex_large,
                           self.controller.update_all, req, self.uuid,
                           body=data)
 
         # test for empty key.
         data = {"metadata": {"": "value1"}}
-        req.body = jsonutils.dump_as_bytes(data)
+        req.body = jsonutils.dumps(data)
         self.assertRaises(self.validation_ex,
                           self.controller.update_all, req, self.uuid,
                           body=data)
 
 
+class ServerMetaDataTestV2(ServerMetaDataTestV21):
+    validation_ex = webob.exc.HTTPBadRequest
+    validation_ex_large = webob.exc.HTTPRequestEntityTooLarge
+
+    def _set_up_resources(self):
+        self.controller = server_metadata_v2.Controller()
+        self.uuid = str(uuid.uuid4())
+        self.url = '/v1.1/fake/servers/%s/metadata' % self.uuid
+
+    def _get_request(self, param_url=''):
+        return fakes.HTTPRequest.blank(self.url + param_url)
+
+
 class BadStateServerMetaDataTestV21(test.TestCase):
 
     def setUp(self):
         super(BadStateServerMetaDataTestV21, self).setUp()
-        fakes.stub_out_key_pair_funcs(self)
-        self.stub_out('nova.db.instance_metadata_get',
-                      return_server_metadata)
+        fakes.stub_out_key_pair_funcs(self.stubs)
+        self.stubs.Set(nova.db, 'instance_metadata_get',
+                       return_server_metadata)
         self.stubs.Set(compute_rpcapi.ComputeAPI, 'change_instance_metadata',
                        fake_change_instance_metadata)
-        self.stub_out('nova.db.instance_get', self._return_server_in_build)
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      self._return_server_in_build_by_uuid)
-        self.stub_out('nova.db.instance_metadata_delete',
-                      delete_server_metadata)
+        self.stubs.Set(nova.db, 'instance_get', self._return_server_in_build)
+        self.stubs.Set(nova.db, 'instance_get_by_uuid',
+                self._return_server_in_build_by_uuid)
+        self.stubs.Set(nova.db, 'instance_metadata_delete',
+                       delete_server_metadata)
         self._set_up_resources()
 
     def _set_up_resources(self):
@@ -689,7 +703,7 @@ class BadStateServerMetaDataTestV21(test.TestCase):
         self.url = '/fake/servers/%s/metadata' % self.uuid
 
     def _get_request(self, param_url=''):
-        return fakes.HTTPRequestV21.blank(self.url + param_url)
+        return fakes.HTTPRequestV3.blank(self.url + param_url)
 
     def test_invalid_state_on_delete(self):
         req = self._get_request('/key2')
@@ -698,8 +712,8 @@ class BadStateServerMetaDataTestV21(test.TestCase):
                           req, self.uuid, 'key2')
 
     def test_invalid_state_on_update_metadata(self):
-        self.stub_out('nova.db.instance_metadata_update',
-                      return_create_instance_metadata)
+        self.stubs.Set(nova.db, 'instance_metadata_update',
+                       return_create_instance_metadata)
         req = self._get_request()
         req.method = 'POST'
         req.content_type = 'application/json'
@@ -709,7 +723,7 @@ class BadStateServerMetaDataTestV21(test.TestCase):
                 'key29': 'newkey',
             }
         }
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         self.assertRaises(webob.exc.HTTPConflict, self.controller.update_all,
                 req, self.uuid, body=expected)
 
@@ -742,11 +756,21 @@ class BadStateServerMetaDataTestV21(test.TestCase):
                 'keydummy': 'newkey',
             }
         }
-        req.body = jsonutils.dump_as_bytes(expected)
+        req.body = jsonutils.dumps(expected)
         self.assertRaises(webob.exc.HTTPConflict, self.controller.update_all,
                 req, self.uuid, body=expected)
 
 
+class BadStateServerMetaDataTestV2(BadStateServerMetaDataTestV21):
+    def _set_up_resources(self):
+        self.controller = server_metadata_v2.Controller()
+        self.uuid = str(uuid.uuid4())
+        self.url = '/v1.1/fake/servers/%s/metadata' % self.uuid
+
+    def _get_request(self, param_url=''):
+        return fakes.HTTPRequest.blank(self.url + param_url)
+
+
 class ServerMetaPolicyEnforcementV21(test.NoDBTestCase):
 
     def setUp(self):
