@@ -17,20 +17,12 @@
 Tests for Block Device utility functions.
 """
 
-from unittest import mock
-
-from oslo_utils.fixture import uuidsentinel as uuids
-from oslo_utils import units
-
 from nova import block_device
-from nova.compute import api as compute_api
-from nova import context
 from nova import exception
 from nova import objects
 from nova import test
 from nova.tests.unit import fake_block_device
 from nova.tests.unit import matchers
-from nova.volume import cinder
 
 
 class BlockDeviceTestCase(test.NoDBTestCase):
@@ -39,7 +31,7 @@ class BlockDeviceTestCase(test.NoDBTestCase):
         BDM = block_device.BlockDeviceDict
 
         self.new_mapping = [
-            BDM({'id': 1, 'instance_uuid': uuids.instance,
+            BDM({'id': 1, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sdb1',
                  'source_type': 'blank',
                  'destination_type': 'local',
@@ -47,21 +39,21 @@ class BlockDeviceTestCase(test.NoDBTestCase):
                  'volume_size': 1,
                  'guest_format': 'swap',
                  'boot_index': -1}),
-            BDM({'id': 2, 'instance_uuid': uuids.instance,
+            BDM({'id': 2, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sdc1',
                  'source_type': 'blank',
                  'destination_type': 'local',
                  'volume_size': 10,
                  'delete_on_termination': True,
                  'boot_index': -1}),
-            BDM({'id': 3, 'instance_uuid': uuids.instance,
+            BDM({'id': 3, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sda1',
                  'source_type': 'volume',
                  'destination_type': 'volume',
                  'volume_id': 'fake-volume-id-1',
                  'connection_info': "{'fake': 'connection_info'}",
                  'boot_index': 0}),
-            BDM({'id': 4, 'instance_uuid': uuids.instance,
+            BDM({'id': 4, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sda2',
                  'source_type': 'snapshot',
                  'destination_type': 'volume',
@@ -69,7 +61,7 @@ class BlockDeviceTestCase(test.NoDBTestCase):
                  'snapshot_id': 'fake-snapshot-id-1',
                  'volume_id': 'fake-volume-id-2',
                  'boot_index': -1}),
-            BDM({'id': 5, 'instance_uuid': uuids.instance,
+            BDM({'id': 5, 'instance_uuid': 'fake-instance',
                  'no_device': True,
                  'device_name': '/dev/vdc'}),
         ]
@@ -85,10 +77,12 @@ class BlockDeviceTestCase(test.NoDBTestCase):
                        'root_device_name': root_device1}
 
         self.assertIsNone(block_device.properties_root_device_name({}))
-        self.assertEqual(root_device0,
-                         block_device.properties_root_device_name(properties0))
-        self.assertEqual(root_device1,
-                         block_device.properties_root_device_name(properties1))
+        self.assertEqual(
+            block_device.properties_root_device_name(properties0),
+            root_device0)
+        self.assertEqual(
+            block_device.properties_root_device_name(properties1),
+            root_device1)
 
     def test_ephemeral(self):
         self.assertFalse(block_device.is_ephemeral('ephemeral'))
@@ -99,9 +93,9 @@ class BlockDeviceTestCase(test.NoDBTestCase):
         self.assertFalse(block_device.is_ephemeral('swap'))
         self.assertFalse(block_device.is_ephemeral('/dev/sda1'))
 
-        self.assertEqual(0, block_device.ephemeral_num('ephemeral0'))
-        self.assertEqual(1, block_device.ephemeral_num('ephemeral1'))
-        self.assertEqual(11, block_device.ephemeral_num('ephemeral11'))
+        self.assertEqual(block_device.ephemeral_num('ephemeral0'), 0)
+        self.assertEqual(block_device.ephemeral_num('ephemeral1'), 1)
+        self.assertEqual(block_device.ephemeral_num('ephemeral11'), 11)
 
         self.assertFalse(block_device.is_swap_or_ephemeral('ephemeral'))
         self.assertTrue(block_device.is_swap_or_ephemeral('ephemeral0'))
@@ -128,46 +122,28 @@ class BlockDeviceTestCase(test.NoDBTestCase):
             {'virtual': 'ephemeral2', 'device': '/dev/sde'}]
 
         prepended = block_device.mappings_prepend_dev(mapping)
-        self.assertEqual(sorted(expected, key=lambda v: v['virtual']),
-                         sorted(prepended, key=lambda v: v['virtual']))
+        self.assertEqual(prepended.sort(), expected.sort())
 
     def test_strip_dev(self):
-        self.assertEqual('sda', block_device.strip_dev('/dev/sda'))
-        self.assertEqual('sda', block_device.strip_dev('sda'))
-        self.assertIsNone(block_device.strip_dev(None))
+        self.assertEqual(block_device.strip_dev('/dev/sda'), 'sda')
+        self.assertEqual(block_device.strip_dev('sda'), 'sda')
 
     def test_strip_prefix(self):
-        self.assertEqual('a', block_device.strip_prefix('/dev/sda'))
-        self.assertEqual('a', block_device.strip_prefix('a'))
-        self.assertEqual('a', block_device.strip_prefix('xvda'))
-        self.assertEqual('a', block_device.strip_prefix('vda'))
-        self.assertEqual('a', block_device.strip_prefix('hda'))
-        self.assertIsNone(block_device.strip_prefix(None))
+        self.assertEqual(block_device.strip_prefix('/dev/sda'), 'a')
+        self.assertEqual(block_device.strip_prefix('a'), 'a')
+        self.assertEqual(block_device.strip_prefix('xvda'), 'a')
+        self.assertEqual(block_device.strip_prefix('vda'), 'a')
+        self.assertEqual(block_device.strip_prefix('hda'), 'a')
 
     def test_get_device_letter(self):
-        self.assertEqual('', block_device.get_device_letter(''))
-        self.assertEqual('a', block_device.get_device_letter('/dev/sda1'))
-        self.assertEqual('b', block_device.get_device_letter('/dev/xvdb'))
-        self.assertEqual('d', block_device.get_device_letter('/dev/d'))
-        self.assertEqual('a', block_device.get_device_letter('a'))
-        self.assertEqual('b', block_device.get_device_letter('sdb2'))
-        self.assertEqual('c', block_device.get_device_letter('vdc'))
-        self.assertEqual('c', block_device.get_device_letter('hdc'))
-        self.assertIsNone(block_device.get_device_letter(None))
-
-    def test_generate_device_name(self):
-        expected = (
-                ('vda', ("vd", 0)),
-                ('vdaa', ("vd", 26)),
-                ('vdabc', ("vd", 730)),
-                ('vdidpok', ("vd", 4194304)),
-                ('sdc', ("sd", 2)),
-                ('sdaa', ("sd", 26)),
-                ('sdiw', ("sd", 256)),
-                ('hdzz', ("hd", 701))
-                )
-        for res, args in expected:
-            self.assertEqual(res, block_device.generate_device_name(*args))
+        self.assertEqual(block_device.get_device_letter(''), '')
+        self.assertEqual(block_device.get_device_letter('/dev/sda1'), 'a')
+        self.assertEqual(block_device.get_device_letter('/dev/xvdb'), 'b')
+        self.assertEqual(block_device.get_device_letter('/dev/d'), 'd')
+        self.assertEqual(block_device.get_device_letter('a'), 'a')
+        self.assertEqual(block_device.get_device_letter('sdb2'), 'b')
+        self.assertEqual(block_device.get_device_letter('vdc'), 'c')
+        self.assertEqual(block_device.get_device_letter('hdc'), 'c')
 
     def test_volume_in_mapping(self):
         swap = {'device_name': '/dev/sdb',
@@ -193,7 +169,7 @@ class BlockDeviceTestCase(test.NoDBTestCase):
         def _assert_volume_in_mapping(device_name, true_or_false):
             in_mapping = block_device.volume_in_mapping(
                     device_name, block_device_info)
-            self.assertEqual(true_or_false, in_mapping)
+            self.assertEqual(in_mapping, true_or_false)
 
         _assert_volume_in_mapping('sda', False)
         _assert_volume_in_mapping('sdb', True)
@@ -275,58 +251,58 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         BDM = block_device.BlockDeviceDict
 
         self.api_mapping = [
-            {'id': 1, 'instance_uuid': uuids.instance,
+            {'id': 1, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sdb1',
              'source_type': 'blank',
              'destination_type': 'local',
              'delete_on_termination': True,
              'guest_format': 'swap',
              'boot_index': -1},
-            {'id': 2, 'instance_uuid': uuids.instance,
+            {'id': 2, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sdc1',
              'source_type': 'blank',
              'destination_type': 'local',
              'delete_on_termination': True,
              'boot_index': -1},
-            {'id': 3, 'instance_uuid': uuids.instance,
+            {'id': 3, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sda1',
              'source_type': 'volume',
              'destination_type': 'volume',
              'uuid': 'fake-volume-id-1',
              'boot_index': 0},
-            {'id': 4, 'instance_uuid': uuids.instance,
+            {'id': 4, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sda2',
              'source_type': 'snapshot',
              'destination_type': 'volume',
              'uuid': 'fake-snapshot-id-1',
              'boot_index': -1},
-            {'id': 5, 'instance_uuid': uuids.instance,
+            {'id': 5, 'instance_uuid': 'fake-instance',
              'no_device': True,
              'device_name': '/dev/vdc'},
         ]
 
         self.new_mapping = [
-            BDM({'id': 1, 'instance_uuid': uuids.instance,
+            BDM({'id': 1, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sdb1',
                  'source_type': 'blank',
                  'destination_type': 'local',
                  'delete_on_termination': True,
                  'guest_format': 'swap',
                  'boot_index': -1}),
-            BDM({'id': 2, 'instance_uuid': uuids.instance,
+            BDM({'id': 2, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sdc1',
                  'source_type': 'blank',
                  'destination_type': 'local',
                  'delete_on_termination': True,
                  'boot_index': -1}),
-            BDM({'id': 3, 'instance_uuid': uuids.instance,
+            BDM({'id': 3, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sda1',
                  'source_type': 'volume',
                  'destination_type': 'volume',
                  'volume_id': 'fake-volume-id-1',
                  'connection_info': "{'fake': 'connection_info'}",
                  'boot_index': 0}),
-            BDM({'id': 4, 'instance_uuid': uuids.instance,
+            BDM({'id': 4, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sda2',
                  'source_type': 'snapshot',
                  'destination_type': 'volume',
@@ -334,43 +310,43 @@ class TestBlockDeviceDict(test.NoDBTestCase):
                  'snapshot_id': 'fake-snapshot-id-1',
                  'volume_id': 'fake-volume-id-2',
                  'boot_index': -1}),
-            BDM({'id': 5, 'instance_uuid': uuids.instance,
+            BDM({'id': 5, 'instance_uuid': 'fake-instance',
                  'no_device': True,
                  'device_name': '/dev/vdc'}),
         ]
 
         self.legacy_mapping = [
-            {'id': 1, 'instance_uuid': uuids.instance,
+            {'id': 1, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sdb1',
              'delete_on_termination': True,
              'virtual_name': 'swap'},
-            {'id': 2, 'instance_uuid': uuids.instance,
+            {'id': 2, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sdc1',
              'delete_on_termination': True,
              'virtual_name': 'ephemeral0'},
-            {'id': 3, 'instance_uuid': uuids.instance,
+            {'id': 3, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sda1',
              'volume_id': 'fake-volume-id-1',
              'connection_info': "{'fake': 'connection_info'}"},
-            {'id': 4, 'instance_uuid': uuids.instance,
+            {'id': 4, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sda2',
              'connection_info': "{'fake': 'connection_info'}",
              'snapshot_id': 'fake-snapshot-id-1',
              'volume_id': 'fake-volume-id-2'},
-            {'id': 5, 'instance_uuid': uuids.instance,
+            {'id': 5, 'instance_uuid': 'fake-instance',
              'no_device': True,
              'device_name': '/dev/vdc'},
         ]
 
         self.new_mapping_source_image = [
-            BDM({'id': 6, 'instance_uuid': uuids.instance,
+            BDM({'id': 6, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sda3',
                  'source_type': 'image',
                  'destination_type': 'volume',
                  'connection_info': "{'fake': 'connection_info'}",
                  'volume_id': 'fake-volume-id-3',
                  'boot_index': -1}),
-            BDM({'id': 7, 'instance_uuid': uuids.instance,
+            BDM({'id': 7, 'instance_uuid': 'fake-instance',
                  'device_name': '/dev/sda4',
                  'source_type': 'image',
                  'destination_type': 'local',
@@ -380,7 +356,7 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         ]
 
         self.legacy_mapping_source_image = [
-            {'id': 6, 'instance_uuid': uuids.instance,
+            {'id': 6, 'instance_uuid': 'fake-instance',
              'device_name': '/dev/sda3',
              'connection_info': "{'fake': 'connection_info'}",
              'volume_id': 'fake-volume-id-3'},
@@ -390,11 +366,11 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         def fake_validate(obj, dct):
             pass
 
-        self.stub_out('nova.block_device.BlockDeviceDict._fields',
+        self.stubs.Set(block_device.BlockDeviceDict, '_fields',
                        set(['field1', 'field2']))
-        self.stub_out('nova.block_device.BlockDeviceDict._db_only_fields',
+        self.stubs.Set(block_device.BlockDeviceDict, '_db_only_fields',
                        set(['db_field1', 'db_field2']))
-        self.stub_out('nova.block_device.BlockDeviceDict._validate',
+        self.stubs.Set(block_device.BlockDeviceDict, '_validate',
                        fake_validate)
 
         # Make sure db fields are not picked up if they are not
@@ -434,7 +410,7 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         self.assertEqual('bar', dev_dict['field2'])
 
     def test_init_prepend_dev_to_device_name(self):
-        bdm = {'id': 3, 'instance_uuid': uuids.instance,
+        bdm = {'id': 3, 'instance_uuid': 'fake-instance',
                'device_name': 'vda',
                'source_type': 'volume',
                'destination_type': 'volume',
@@ -451,18 +427,6 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         bdm_dict = block_device.BlockDeviceDict(bdm)
         self.assertIsNone(bdm_dict['device_name'])
 
-    def test_init_boolify_delete_on_termination(self):
-        # Make sure that when delete_on_termination is not passed it's
-        # still set to False and not None
-        bdm = {'id': 3, 'instance_uuid': uuids.instance,
-               'device_name': 'vda',
-               'source_type': 'volume',
-               'destination_type': 'volume',
-               'volume_id': 'fake-volume-id-1',
-               'boot_index': 0}
-        bdm_dict = block_device.BlockDeviceDict(bdm)
-        self.assertFalse(bdm_dict['delete_on_termination'])
-
     def test_validate(self):
         self.assertRaises(exception.InvalidBDMFormat,
                           block_device.BlockDeviceDict,
@@ -492,7 +456,7 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         cool_volume_size_bdm['volume_size'] = '42'
         cool_volume_size_bdm = block_device.BlockDeviceDict(
             cool_volume_size_bdm)
-        self.assertEqual(42, cool_volume_size_bdm['volume_size'])
+        self.assertEqual(cool_volume_size_bdm['volume_size'], 42)
 
         lame_volume_size_bdm = dict(self.new_mapping[2])
         lame_volume_size_bdm['volume_size'] = 'some_non_int_string'
@@ -503,7 +467,7 @@ class TestBlockDeviceDict(test.NoDBTestCase):
         truthy_bdm = dict(self.new_mapping[2])
         truthy_bdm['delete_on_termination'] = '1'
         truthy_bdm = block_device.BlockDeviceDict(truthy_bdm)
-        self.assertTrue(truthy_bdm['delete_on_termination'])
+        self.assertEqual(truthy_bdm['delete_on_termination'], True)
 
         verbose_bdm = dict(self.new_mapping[2])
         verbose_bdm['boot_index'] = 'first'
@@ -522,12 +486,10 @@ class TestBlockDeviceDict(test.NoDBTestCase):
             return [bdm for bdm in bdms if bdm['source_type'] == 'image']
 
         def _get_bootable_bdms(bdms):
-            return [bdm for bdm in bdms
-                    if (bdm['boot_index'] is not None and
-                        bdm['boot_index'] >= 0)]
+            return [bdm for bdm in bdms if bdm['boot_index'] >= 0]
 
         new_no_img = block_device.from_legacy_mapping(self.legacy_mapping)
-        self.assertEqual(0, len(_get_image_bdms(new_no_img)))
+        self.assertEqual(len(_get_image_bdms(new_no_img)), 0)
 
         for new, expected in zip(new_no_img, self.new_mapping):
             self.assertThat(new, matchers.IsSubDictOf(expected))
@@ -536,24 +498,24 @@ class TestBlockDeviceDict(test.NoDBTestCase):
             self.legacy_mapping, 'fake_image_ref')
         image_bdms = _get_image_bdms(new_with_img)
         boot_bdms = _get_bootable_bdms(new_with_img)
-        self.assertEqual(1, len(image_bdms))
-        self.assertEqual(1, len(boot_bdms))
-        self.assertEqual(0, image_bdms[0]['boot_index'])
-        self.assertEqual('image', boot_bdms[0]['source_type'])
+        self.assertEqual(len(image_bdms), 1)
+        self.assertEqual(len(boot_bdms), 1)
+        self.assertEqual(image_bdms[0]['boot_index'], 0)
+        self.assertEqual(boot_bdms[0]['source_type'], 'image')
 
         new_with_img_and_root = block_device.from_legacy_mapping(
             self.legacy_mapping, 'fake_image_ref', 'sda1')
         image_bdms = _get_image_bdms(new_with_img_and_root)
         boot_bdms = _get_bootable_bdms(new_with_img_and_root)
-        self.assertEqual(0, len(image_bdms))
-        self.assertEqual(1, len(boot_bdms))
-        self.assertEqual(0, boot_bdms[0]['boot_index'])
-        self.assertEqual('volume', boot_bdms[0]['source_type'])
+        self.assertEqual(len(image_bdms), 0)
+        self.assertEqual(len(boot_bdms), 1)
+        self.assertEqual(boot_bdms[0]['boot_index'], 0)
+        self.assertEqual(boot_bdms[0]['source_type'], 'volume')
 
         new_no_root = block_device.from_legacy_mapping(
             self.legacy_mapping, 'fake_image_ref', 'sda1', no_root=True)
-        self.assertEqual(0, len(_get_image_bdms(new_no_root)))
-        self.assertEqual(0, len(_get_bootable_bdms(new_no_root)))
+        self.assertEqual(len(_get_image_bdms(new_no_root)), 0)
+        self.assertEqual(len(_get_bootable_bdms(new_no_root)), 0)
 
     def test_from_api(self):
         for api, new in zip(self.api_mapping, self.new_mapping):
@@ -599,67 +561,53 @@ class TestBlockDeviceDict(test.NoDBTestCase):
              'destination_type': 'local',
              'volume_id': 'fake-volume-id-1',
              'boot_index': 0})
-        self.assertEqual(retexp,
-                         block_device.BlockDeviceDict.from_api(api_dict, True))
+        self.assertEqual(
+            block_device.BlockDeviceDict.from_api(api_dict, True),
+            retexp)
 
-    def test_from_api_valid_source_to_local_mapping_with_string_bi(self):
-        api_dict = {'id': 1,
-                    'source_type': 'image',
-                    'destination_type': 'local',
-                    'volume_id': 'fake-volume-id-1',
-                    'uuid': 1,
-                    'boot_index': '0'}
+    def test_legacy(self):
+        for legacy, new in zip(self.legacy_mapping, self.new_mapping):
+            self.assertThat(
+                legacy,
+                matchers.IsSubDictOf(new.legacy()))
 
-        retexp = block_device.BlockDeviceDict(
-            {'id': 1,
-             'source_type': 'image',
-             'image_id': 1,
-             'destination_type': 'local',
-             'volume_id': 'fake-volume-id-1',
-             'boot_index': 0})
-        self.assertEqual(retexp,
-                         block_device.BlockDeviceDict.from_api(api_dict, True))
+    def test_legacy_mapping(self):
+        got_legacy = block_device.legacy_mapping(self.new_mapping)
 
-    def test_from_api_invalid_image_to_destination_local_mapping(self):
-        api_dict = {'id': 1,
-                    'source_type': 'image',
-                    'destination_type': 'local',
-                    'uuid': 'fake-volume-id-1',
-                    'volume_type': 'fake-lvm-1',
-                    'boot_index': 1}
-        ex = self.assertRaises(exception.InvalidBDMFormat,
-                               block_device.BlockDeviceDict.from_api,
-                               api_dict, False)
-        self.assertIn('Mapping image to local is not supported', str(ex))
+        for legacy, expected in zip(got_legacy, self.legacy_mapping):
+            self.assertThat(expected, matchers.IsSubDictOf(legacy))
 
-    def test_from_api_invalid_volume_type_to_destination_local_mapping(self):
-        api_dict = {'id': 1,
-                    'source_type': 'volume',
-                    'destination_type': 'local',
-                    'uuid': 'fake-volume-id-1',
-                    'volume_type': 'fake-lvm-1'}
-        ex = self.assertRaises(exception.InvalidBDMFormat,
-                               block_device.BlockDeviceDict.from_api,
-                               api_dict, False)
-        self.assertIn('Specifying a volume_type with destination_type=local '
-                      'is not supported', str(ex))
+    def test_legacy_source_image(self):
+        for legacy, new in zip(self.legacy_mapping_source_image,
+                               self.new_mapping_source_image):
+            if new['destination_type'] == 'volume':
+                self.assertThat(legacy, matchers.IsSubDictOf(new.legacy()))
+            else:
+                self.assertRaises(exception.InvalidBDMForLegacy, new.legacy)
 
-    def test_from_api_invalid_specify_volume_type_with_source_volume_mapping(
-            self):
-        api_dict = {'id': 1,
-                    'source_type': 'volume',
-                    'destination_type': 'volume',
-                    'uuid': 'fake-volume-id-1',
-                    'volume_type': 'fake-lvm-1'}
-        ex = self.assertRaises(exception.InvalidBDMFormat,
-                               block_device.BlockDeviceDict.from_api,
-                               api_dict, False)
-        self.assertIn('Specifying volume type to existing volume is '
-                      'not supported', str(ex))
+    def test_legacy_mapping_source_image(self):
+        got_legacy = block_device.legacy_mapping(self.new_mapping)
+
+        for legacy, expected in zip(got_legacy, self.legacy_mapping):
+            self.assertThat(expected, matchers.IsSubDictOf(legacy))
+
+    def test_legacy_mapping_from_object_list(self):
+        bdm1 = objects.BlockDeviceMapping()
+        bdm1 = objects.BlockDeviceMapping._from_db_object(
+            None, bdm1, fake_block_device.FakeDbBlockDeviceDict(
+                self.new_mapping[0]))
+        bdm2 = objects.BlockDeviceMapping()
+        bdm2 = objects.BlockDeviceMapping._from_db_object(
+            None, bdm2, fake_block_device.FakeDbBlockDeviceDict(
+                self.new_mapping[1]))
+        bdmlist = objects.BlockDeviceMappingList()
+        bdmlist.objects = [bdm1, bdm2]
+        block_device.legacy_mapping(bdmlist)
 
     def test_image_mapping(self):
         removed_fields = ['id', 'instance_uuid', 'connection_info',
-                          'created_at', 'updated_at', 'deleted_at', 'deleted']
+                          'device_name', 'created_at', 'updated_at',
+                          'deleted_at', 'deleted']
         for bdm in self.new_mapping:
             mapping_bdm = fake_block_device.FakeDbBlockDeviceDict(
                     bdm).get_image_mapping()
@@ -668,19 +616,15 @@ class TestBlockDeviceDict(test.NoDBTestCase):
 
     def _test_snapshot_from_bdm(self, template):
         snapshot = block_device.snapshot_from_bdm('new-snapshot-id', template)
-        self.assertEqual('new-snapshot-id', snapshot['snapshot_id'])
-        self.assertEqual('snapshot', snapshot['source_type'])
-        self.assertEqual('volume', snapshot['destination_type'])
-        self.assertEqual(template.volume_size, snapshot['volume_size'])
-        self.assertEqual(template.delete_on_termination,
-                         snapshot['delete_on_termination'])
-        self.assertEqual(template.device_name, snapshot['device_name'])
+        self.assertEqual(snapshot['snapshot_id'], 'new-snapshot-id')
+        self.assertEqual(snapshot['source_type'], 'snapshot')
+        self.assertEqual(snapshot['destination_type'], 'volume')
         for key in ['disk_bus', 'device_type', 'boot_index']:
-            self.assertEqual(template[key], snapshot[key])
+            self.assertEqual(snapshot[key], template[key])
 
     def test_snapshot_from_bdm(self):
         for bdm in self.new_mapping:
-            self._test_snapshot_from_bdm(objects.BlockDeviceMapping(**bdm))
+            self._test_snapshot_from_bdm(bdm)
 
     def test_snapshot_from_object(self):
         for bdm in self.new_mapping[:-1]:
@@ -689,177 +633,3 @@ class TestBlockDeviceDict(test.NoDBTestCase):
                    None, obj, fake_block_device.FakeDbBlockDeviceDict(
                        bdm))
             self._test_snapshot_from_bdm(obj)
-
-
-class GetBDMImageMetadataTestCase(test.NoDBTestCase):
-
-    def setUp(self):
-        super().setUp()
-        self.compute_api = compute_api.API()
-        self.context = context.RequestContext('fake', 'fake')
-
-    def _test_get_bdm_image_metadata__bootable(self, is_bootable=False):
-        block_device_mapping = [{
-            'id': 1,
-            'device_name': 'vda',
-            'no_device': None,
-            'virtual_name': None,
-            'snapshot_id': None,
-            'volume_id': '1',
-            'delete_on_termination': False,
-        }]
-
-        expected_meta = {
-            'min_disk': 0, 'min_ram': 0, 'properties': {}, 'size': 0,
-            'status': 'active',
-        }
-
-        def get_vol_data(*args, **kwargs):
-            return {'bootable': is_bootable}
-
-        with mock.patch.object(
-            self.compute_api.volume_api, 'get', side_effect=get_vol_data,
-        ):
-            if not is_bootable:
-                self.assertRaises(
-                    exception.InvalidBDMVolumeNotBootable,
-                    block_device.get_bdm_image_metadata,
-                    self.context,
-                    self.compute_api.image_api,
-                    self.compute_api.volume_api,
-                    block_device_mapping)
-            else:
-                meta = block_device.get_bdm_image_metadata(
-                    self.context, self.compute_api.image_api,
-                    self.compute_api.volume_api, block_device_mapping)
-                self.assertEqual(expected_meta, meta)
-
-    def test_get_bdm_image_metadata__non_bootable(self):
-        self._test_get_bdm_image_metadata__bootable(False)
-
-    def test_get_bdm_image_metadata__bootable(self):
-        self._test_get_bdm_image_metadata__bootable(True)
-
-    def test_get_bdm_image_metadata__basic_property(self):
-        block_device_mapping = [{
-            'id': 1,
-            'device_name': 'vda',
-            'no_device': None,
-            'virtual_name': None,
-            'snapshot_id': None,
-            'volume_id': '1',
-            'delete_on_termination': False,
-        }]
-        fake_volume = {
-            'volume_image_metadata': {
-                'min_ram': 256, 'min_disk': 128, 'foo': 'bar',
-            },
-        }
-        with mock.patch.object(
-            self.compute_api.volume_api, 'get', return_value=fake_volume,
-        ):
-            meta = block_device.get_bdm_image_metadata(
-                self.context, self.compute_api.image_api,
-                self.compute_api.volume_api, block_device_mapping)
-            self.assertEqual(256, meta['min_ram'])
-            self.assertEqual(128, meta['min_disk'])
-            self.assertEqual('active', meta['status'])
-            self.assertEqual('bar', meta['properties']['foo'])
-
-    def test_get_bdm_image_metadata__snapshot_basic_property(self):
-        block_device_mapping = [{
-            'id': 1,
-            'device_name': 'vda',
-            'no_device': None,
-            'virtual_name': None,
-            'snapshot_id': '2',
-            'volume_id': None,
-            'delete_on_termination': False,
-        }]
-        fake_volume = {
-            'volume_image_metadata': {
-                'min_ram': 256, 'min_disk': 128, 'foo': 'bar',
-            },
-        }
-        fake_snapshot = {'volume_id': '1'}
-        with test.nested(
-            mock.patch.object(
-                self.compute_api.volume_api, 'get',
-                return_value=fake_volume),
-            mock.patch.object(
-                self.compute_api.volume_api, 'get_snapshot',
-                return_value=fake_snapshot),
-        ) as (volume_get, volume_get_snapshot):
-            meta = block_device.get_bdm_image_metadata(
-                self.context, self.compute_api.image_api,
-                self.compute_api.volume_api, block_device_mapping)
-
-            self.assertEqual(256, meta['min_ram'])
-            self.assertEqual(128, meta['min_disk'])
-            self.assertEqual('active', meta['status'])
-            self.assertEqual('bar', meta['properties']['foo'])
-            volume_get_snapshot.assert_called_once_with(
-                self.context, block_device_mapping[0]['snapshot_id'])
-            volume_get.assert_called_once_with(
-                self.context, fake_snapshot['volume_id'])
-
-    @mock.patch.object(
-        cinder.API, 'get',
-        side_effect=exception.CinderConnectionFailed(reason='error'))
-    def test_get_bdm_image_metadata__cinder_down(self, mock_get):
-        bdms = [
-            objects.BlockDeviceMapping(
-                **fake_block_device.FakeDbBlockDeviceDict({
-                    'id': 1,
-                    'volume_id': 1,
-                    'source_type': 'volume',
-                    'destination_type': 'volume',
-                    'device_name': 'vda',
-                })
-            )
-        ]
-        self.assertRaises(
-            exception.CinderConnectionFailed,
-            block_device.get_bdm_image_metadata,
-            self.context,
-            self.compute_api.image_api,
-            self.compute_api.volume_api,
-            bdms, legacy_bdm=True)
-
-
-class GetImageMetadataFromVolumeTestCase(test.NoDBTestCase):
-    def test_inherit_image_properties(self):
-        properties = {'fake_prop': 'fake_value'}
-        volume = {'volume_image_metadata': properties}
-        image_meta = block_device.get_image_metadata_from_volume(volume)
-        self.assertEqual(properties, image_meta['properties'])
-
-    def test_image_size(self):
-        volume = {'size': 10}
-        image_meta = block_device.get_image_metadata_from_volume(volume)
-        self.assertEqual(10 * units.Gi, image_meta['size'])
-
-    def test_image_status(self):
-        volume = {}
-        image_meta = block_device.get_image_metadata_from_volume(volume)
-        self.assertEqual('active', image_meta['status'])
-
-    def test_values_conversion(self):
-        properties = {'min_ram': '5', 'min_disk': '7'}
-        volume = {'volume_image_metadata': properties}
-        image_meta = block_device.get_image_metadata_from_volume(volume)
-        self.assertEqual(5, image_meta['min_ram'])
-        self.assertEqual(7, image_meta['min_disk'])
-
-    def test_suppress_not_image_properties(self):
-        properties = {
-            'min_ram': '256', 'min_disk': '128', 'image_id': 'fake_id',
-            'image_name': 'fake_name', 'container_format': 'ami',
-            'disk_format': 'ami', 'size': '1234', 'checksum': 'fake_checksum',
-        }
-        volume = {'volume_image_metadata': properties}
-        image_meta = block_device.get_image_metadata_from_volume(volume)
-        self.assertEqual({}, image_meta['properties'])
-        self.assertEqual(0, image_meta['size'])
-        # volume's properties should not be touched
-        self.assertNotEqual({}, properties)
