@@ -12,32 +12,28 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from collections import deque
+import base64
 import sys
 import traceback
-from unittest import mock
 
 import fixtures
+import mock
 import netaddr
-import os_resource_classes as orc
-import os_vif
-from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import importutils
 from oslo_utils import timeutils
+import six
 
 from nova.compute import manager
-from nova import conf
 from nova.console import type as ctype
-from nova import context
 from nova import exception
 from nova import objects
 from nova import test
-from nova.tests import fixtures as nova_fixtures
-from nova.tests.fixtures import libvirt as fakelibvirt
 from nova.tests.unit import fake_block_device
+from nova.tests.unit.image import fake as fake_image
 from nova.tests.unit import utils as test_utils
+from nova.tests.unit.virt.libvirt import fake_libvirt_utils
 from nova.virt import block_device as driver_block_device
 from nova.virt import event as virtevent
 from nova.virt import fake
@@ -46,7 +42,6 @@ from nova.virt import libvirt
 from nova.virt.libvirt import imagebackend
 
 LOG = logging.getLogger(__name__)
-CONF = conf.CONF
 
 
 def catch_notimplementederror(f):
@@ -55,14 +50,13 @@ def catch_notimplementederror(f):
     If a particular call makes a driver raise NotImplementedError, we
     log it so that we can extract this information afterwards as needed.
     """
-
     def wrapped_func(self, *args, **kwargs):
         try:
             return f(self, *args, **kwargs)
         except NotImplementedError:
             frame = traceback.extract_tb(sys.exc_info()[2])[-1]
             LOG.error("%(driver)s does not implement %(method)s "
-                      "required for test %(test)s",
+                      "required for test %(test)s" %
                       {'driver': type(self.connection),
                        'method': frame[2], 'test': f.__name__})
 
@@ -84,49 +78,80 @@ class _FakeDriverBackendTestCase(object):
         else:
             self.saved_libvirt = None
 
-        self.useFixture(nova_fixtures.OSBrickFixture())
-        self.useFixture(nova_fixtures.LibvirtImageBackendFixture())
-        self.useFixture(nova_fixtures.LibvirtFixture())
+        import nova.tests.unit.virt.libvirt.fake_imagebackend as \
+            fake_imagebackend
+        import nova.tests.unit.virt.libvirt.fake_libvirt_utils as \
+            fake_libvirt_utils
+        import nova.tests.unit.virt.libvirt.fakelibvirt as fakelibvirt
+
+        sys.modules['libvirt'] = fakelibvirt
+        import nova.virt.libvirt.driver
+        import nova.virt.libvirt.firewall
+        import nova.virt.libvirt.host
 
         self.useFixture(fixtures.MonkeyPatch(
-            'nova.virt.libvirt.host.Host._conn_event_thread',
-            lambda *args: None))
+            'nova.virt.libvirt.driver.imagebackend',
+            fake_imagebackend))
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.virt.libvirt.driver.libvirt',
+            fakelibvirt))
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.virt.libvirt.driver.libvirt_utils',
+            fake_libvirt_utils))
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.virt.libvirt.host.libvirt',
+            fakelibvirt))
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.virt.libvirt.imagebackend.libvirt_utils',
+            fake_libvirt_utils))
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.virt.libvirt.firewall.libvirt',
+            fakelibvirt))
+
+        fakelibvirt.disable_event_thread(self)
 
         self.flags(rescue_image_id="2",
                    rescue_kernel_id="3",
                    rescue_ramdisk_id=None,
                    snapshots_directory='./',
-                   sysinfo_serial='none',
                    group='libvirt')
 
-        def fake_wait():
+        def fake_extend(image, size):
             pass
 
-        def fake_detach_device_with_retry(_self, get_device_conf_func, device,
-                                          live, *args, **kwargs):
-            # Still calling detach, but instead of returning function
-            # that actually checks if device is gone from XML, just continue
-            # because XML never gets updated in these tests
-            _self.detach_device(get_device_conf_func(device),
-                                live=live)
-            return fake_wait
+        def fake_migrateToURI(*a):
+            pass
+
+        def fake_make_drive(_self, _path):
+            pass
+
+        def fake_get_instance_disk_info(_self, instance, xml=None,
+                                        block_device_info=None):
+            return '[]'
+
+        def fake_delete_instance_files(_self, _instance):
+            pass
+
+        self.stubs.Set(nova.virt.libvirt.driver.LibvirtDriver,
+                       '_get_instance_disk_info',
+                       fake_get_instance_disk_info)
+
+        self.stubs.Set(nova.virt.libvirt.driver.disk,
+                       'extend', fake_extend)
+
+        self.stubs.Set(nova.virt.libvirt.driver.LibvirtDriver,
+                       'delete_instance_files',
+                       fake_delete_instance_files)
+
+        # Like the existing fakelibvirt.migrateToURI, do nothing,
+        # but don't fail for these tests.
+        self.stubs.Set(nova.virt.libvirt.driver.libvirt.Domain,
+                       'migrateToURI', fake_migrateToURI)
 
-        self.stub_out('nova.virt.libvirt.driver.LibvirtDriver.'
-                      '_get_instance_disk_info_from_config',
-                      lambda self, guest_config, block_device_info: [])
-        self.stub_out('nova.virt.disk.api.extend', lambda image, size: None)
-        self.stub_out('nova.virt.libvirt.driver.LibvirtDriver.'
-                      'delete_instance_files', lambda self, instance: None)
-        self.stub_out('nova.virt.libvirt.guest.Guest.detach_device_with_retry',
-                      fake_detach_device_with_retry)
-        self.stub_out('nova.virt.libvirt.guest.Guest.migrate',
-                      lambda self, destination, migrate_uri=None,
-                      migrate_disks=None, destination_xml=None, flags=0,
-                      bandwidth=0: None)
         # We can't actually make a config drive v2 because ensure_tree has
         # been faked out
-        self.stub_out('nova.virt.configdrive.ConfigDriveBuilder.make_drive',
-                      lambda self, path: None)
+        self.stubs.Set(nova.virt.configdrive.ConfigDriveBuilder,
+                       'make_drive', fake_make_drive)
 
     def _teardown_fakelibvirt(self):
         # Restore libvirt
@@ -138,10 +163,11 @@ class _FakeDriverBackendTestCase(object):
         # TODO(sdague): it would be nice to do this in a way that only
         # the relevant backends where replaced for tests, though this
         # should not harm anything by doing it for all backends
-        self.useFixture(nova_fixtures.GlanceFixture(self))
+        fake_image.stub_out_image_service(self.stubs)
         self._setup_fakelibvirt()
 
     def tearDown(self):
+        fake_image.FakeImageService_reset()
         self._teardown_fakelibvirt()
         super(_FakeDriverBackendTestCase, self).tearDown()
 
@@ -153,13 +179,17 @@ class VirtDriverLoaderTestCase(_FakeDriverBackendTestCase, test.TestCase):
     """
 
     # if your driver supports being tested in a fake way, it can go here
+    #
+    # both long form and short form drivers are supported
     new_drivers = {
+        'nova.virt.fake.FakeDriver': 'FakeDriver',
+        'nova.virt.libvirt.LibvirtDriver': 'LibvirtDriver',
         'fake.FakeDriver': 'FakeDriver',
         'libvirt.LibvirtDriver': 'LibvirtDriver'
         }
 
     def test_load_new_drivers(self):
-        for cls, driver in self.new_drivers.items():
+        for cls, driver in self.new_drivers.iteritems():
             self.flags(compute_driver=cls)
             # NOTE(sdague) the try block is to make it easier to debug a
             # failure by knowing which driver broke
@@ -169,13 +199,16 @@ class VirtDriverLoaderTestCase(_FakeDriverBackendTestCase, test.TestCase):
                 self.fail("Couldn't load driver %s - %s" % (cls, e))
 
             self.assertEqual(cm.driver.__class__.__name__, driver,
-                             "Couldn't load driver %s" % cls)
+                             "Could't load driver %s" % cls)
 
-    @mock.patch.object(sys, 'exit', side_effect=test.TestingException())
-    def test_fail_to_load_new_drivers(self, mock_exit):
+    def test_fail_to_load_new_drivers(self):
         self.flags(compute_driver='nova.virt.amiga')
+
+        def _fake_exit(error):
+            raise test.TestingException()
+
+        self.stubs.Set(sys, 'exit', _fake_exit)
         self.assertRaises(test.TestingException, manager.ComputeManager)
-        mock_exit.assert_called_once_with(1)
 
 
 class _VirtDriverTestCase(_FakeDriverBackendTestCase):
@@ -186,24 +219,22 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
         self.connection = importutils.import_object(self.driver_module,
                                                     fake.FakeVirtAPI())
         self.ctxt = test_utils.get_test_admin_context()
-        self.image_service = self.useFixture(nova_fixtures.GlanceFixture(self))
+        self.image_service = fake_image.FakeImageService()
         # NOTE(dripton): resolve_driver_format does some file reading and
         # writing and chowning that complicate testing too much by requiring
         # using real directories with proper permissions.  Just stub it out
         # here; we test it in test_imagebackend.py
-        self.stub_out('nova.virt.libvirt.imagebackend.Image.'
-                      'resolve_driver_format',
-                      imagebackend.Image._get_driver_format)
-        os_vif.initialize()
+        self.stubs.Set(imagebackend.Image, 'resolve_driver_format',
+                       imagebackend.Image._get_driver_format)
 
     def _get_running_instance(self, obj=True):
         instance_ref = test_utils.get_test_instance(obj=obj)
         network_info = test_utils.get_test_network_info()
         network_info[0]['network']['subnets'][0]['meta']['dhcp_server'] = \
             '1.1.1.1'
-        image_meta = test_utils.get_test_image_object(None, instance_ref)
-        self.connection.spawn(self.ctxt, instance_ref, image_meta,
-                              [], 'herp', {}, network_info=network_info)
+        image_info = test_utils.get_test_image_info(None, instance_ref)
+        self.connection.spawn(self.ctxt, instance_ref, image_info,
+                              [], 'herp', network_info=network_info)
         return instance_ref, network_info
 
     @catch_notimplementederror
@@ -240,16 +271,14 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
     def test_snapshot_running(self):
         img_ref = self.image_service.create(self.ctxt, {'name': 'snap-1'})
         instance_ref, network_info = self._get_running_instance()
-        # this test depends on qemu-img
-        # being installed and in the path,
-        # if it is not installed, skip
-        try:
-            self.connection.snapshot(self.ctxt, instance_ref, img_ref['id'],
-                                     lambda *args, **kwargs: None)
-        except processutils.ProcessExecutionError as e:
-            if 'qemu-img' in e.stderr and 'No such file' in e.stderr:
-                self.skipTest("qemu-img not installed")
-            raise e
+        self.connection.snapshot(self.ctxt, instance_ref, img_ref['id'],
+                                 lambda *args, **kwargs: None)
+
+    @catch_notimplementederror
+    def test_post_interrupted_snapshot_cleanup(self):
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.post_interrupted_snapshot_cleanup(self.ctxt,
+                instance_ref)
 
     @catch_notimplementederror
     def test_reboot(self):
@@ -273,6 +302,13 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
         instance, network_info = self._get_running_instance(obj=True)
         self.connection.set_admin_password(instance, 'p4ssw0rd')
 
+    @catch_notimplementederror
+    def test_inject_file(self):
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.inject_file(instance_ref,
+                                    base64.b64encode('/testfile'),
+                                    base64.b64encode('testcontents'))
+
     @catch_notimplementederror
     def test_resume_state_on_host_boot(self):
         instance_ref, network_info = self._get_running_instance()
@@ -281,24 +317,23 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
 
     @catch_notimplementederror
     def test_rescue(self):
-        image_meta = objects.ImageMeta.from_dict({})
+        image_meta = {}
         instance_ref, network_info = self._get_running_instance()
         self.connection.rescue(self.ctxt, instance_ref, network_info,
-                               image_meta, '', None)
+                               image_meta, '')
 
     @catch_notimplementederror
     def test_unrescue_unrescued_instance(self):
-        instance_ref, _ = self._get_running_instance()
-        self.connection.unrescue(self.ctxt, instance_ref)
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.unrescue(instance_ref, network_info)
 
     @catch_notimplementederror
-    @mock.patch('os.unlink')
-    def test_unrescue_rescued_instance(self, mock_unlink):
-        image_meta = objects.ImageMeta.from_dict({})
+    def test_unrescue_rescued_instance(self):
+        image_meta = {}
         instance_ref, network_info = self._get_running_instance()
         self.connection.rescue(self.ctxt, instance_ref, network_info,
-                               image_meta, '', None)
-        self.connection.unrescue(self.ctxt, instance_ref)
+                               image_meta, '')
+        self.connection.unrescue(instance_ref, network_info)
 
     @catch_notimplementederror
     def test_poll_rebooting_instances(self):
@@ -330,11 +365,6 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
         self.connection.power_off(instance_ref)
         self.connection.power_on(self.ctxt, instance_ref, network_info, None)
 
-    @catch_notimplementederror
-    def test_trigger_crash_dump(self):
-        instance_ref, network_info = self._get_running_instance()
-        self.connection.trigger_crash_dump(instance_ref)
-
     @catch_notimplementederror
     def test_soft_delete(self):
         instance_ref, network_info = self._get_running_instance(obj=True)
@@ -404,7 +434,6 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
         self.assertIn('ip', result)
         self.assertIn('initiator', result)
         self.assertIn('host', result)
-        return result
 
     @catch_notimplementederror
     def test_get_volume_connector_storage_ip(self):
@@ -418,10 +447,7 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
         self.assertEqual(storage_ip, result['ip'])
 
     @catch_notimplementederror
-    @mock.patch('threading.Event.wait', new=mock.Mock())
-    @mock.patch.object(libvirt.driver.LibvirtDriver, '_build_device_metadata',
-                       return_value=objects.InstanceDeviceMetadata())
-    def test_attach_detach_volume(self, _):
+    def test_attach_detach_volume(self):
         instance_ref, network_info = self._get_running_instance()
         connection_info = {
             "driver_volume_type": "fake",
@@ -432,14 +458,11 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
             self.connection.attach_volume(None, connection_info, instance_ref,
                                           '/dev/sda'))
         self.assertIsNone(
-            self.connection.detach_volume(mock.sentinel.context,
-                                          connection_info, instance_ref,
-                                          '/dev/sda'))
+            self.connection.detach_volume(connection_info, instance_ref,
+                                      '/dev/sda'))
 
     @catch_notimplementederror
-    @mock.patch.object(libvirt.driver.LibvirtDriver, '_build_device_metadata',
-                       return_value=objects.InstanceDeviceMetadata())
-    def test_swap_volume(self, _):
+    def test_swap_volume(self):
         instance_ref, network_info = self._get_running_instance()
         self.assertIsNone(
             self.connection.attach_volume(None, {'driver_volume_type': 'fake',
@@ -447,7 +470,7 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
                                           instance_ref,
                                           '/dev/sda'))
         self.assertIsNone(
-            self.connection.swap_volume(None, {'driver_volume_type': 'fake',
+            self.connection.swap_volume({'driver_volume_type': 'fake',
                                          'data': {}},
                                         {'driver_volume_type': 'fake',
                                          'data': {}},
@@ -455,10 +478,7 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
                                         '/dev/sda', 2))
 
     @catch_notimplementederror
-    @mock.patch('threading.Event.wait', new=mock.Mock())
-    @mock.patch.object(libvirt.driver.LibvirtDriver, '_build_device_metadata',
-                       return_value=objects.InstanceDeviceMetadata())
-    def test_attach_detach_different_power_states(self, _):
+    def test_attach_detach_different_power_states(self):
         instance_ref, network_info = self._get_running_instance()
         connection_info = {
             "driver_volume_type": "fake",
@@ -474,19 +494,17 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
             'swap': None,
             'ephemerals': [],
             'block_device_mapping': driver_block_device.convert_volumes([
-                objects.BlockDeviceMapping(
-                    self.ctxt,
-                    **fake_block_device.FakeDbBlockDeviceDict(
-                        {'id': 1, 'instance_uuid': instance_ref['uuid'],
-                         'device_name': '/dev/sda',
-                         'source_type': 'volume',
-                         'destination_type': 'volume',
-                         'delete_on_termination': False,
-                         'snapshot_id': None,
-                         'volume_id': 'abcdedf',
-                         'volume_size': None,
-                         'no_device': None
-                         })),
+                fake_block_device.FakeDbBlockDeviceDict(
+                       {'id': 1, 'instance_uuid': instance_ref['uuid'],
+                        'device_name': '/dev/sda',
+                        'source_type': 'volume',
+                        'destination_type': 'volume',
+                        'delete_on_termination': False,
+                        'snapshot_id': None,
+                        'volume_id': 'abcdedf',
+                        'volume_size': None,
+                        'no_device': None
+                        }),
                 ])
         }
         bdm['block_device_mapping'][0]['connection_info'] = (
@@ -495,8 +513,7 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
                 driver_block_device.DriverVolumeBlockDevice, 'save'):
             self.connection.power_on(
                     self.ctxt, instance_ref, network_info, bdm)
-            self.connection.detach_volume(mock.sentinel.context,
-                                          connection_info,
+            self.connection.detach_volume(connection_info,
                                           instance_ref,
                                           '/dev/sda')
 
@@ -532,10 +549,11 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
 
     @catch_notimplementederror
     def test_get_console_output(self):
+        fake_libvirt_utils.files['dummy.log'] = ''
         instance_ref, network_info = self._get_running_instance()
         console_output = self.connection.get_console_output(self.ctxt,
             instance_ref)
-        self.assertIsInstance(console_output, str)
+        self.assertIsInstance(console_output, six.string_types)
 
     @catch_notimplementederror
     def test_get_vnc_console(self):
@@ -550,47 +568,68 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
                                                           instance_ref)
         self.assertIsInstance(spice_console, ctype.ConsoleSpice)
 
+    @catch_notimplementederror
+    def test_get_rdp_console(self):
+        instance_ref, network_info = self._get_running_instance()
+        rdp_console = self.connection.get_rdp_console(self.ctxt, instance_ref)
+        self.assertIsInstance(rdp_console, ctype.ConsoleRDP)
+
     @catch_notimplementederror
     def test_get_serial_console(self):
-        self.flags(enabled=True, group='serial_console')
         instance_ref, network_info = self._get_running_instance()
         serial_console = self.connection.get_serial_console(self.ctxt,
                                                             instance_ref)
         self.assertIsInstance(serial_console, ctype.ConsoleSerial)
 
     @catch_notimplementederror
-    def test_get_mks_console(self):
+    def test_get_console_pool_info(self):
         instance_ref, network_info = self._get_running_instance()
-        mks_console = self.connection.get_mks_console(self.ctxt,
-                                                      instance_ref)
-        self.assertIsInstance(mks_console, ctype.ConsoleMKS)
+        console_pool = self.connection.get_console_pool_info(instance_ref)
+        self.assertIn('address', console_pool)
+        self.assertIn('username', console_pool)
+        self.assertIn('password', console_pool)
 
-    @mock.patch(
-        'nova.tests.fixtures.libvirt.Domain.jobStats',
-        new=mock.Mock(return_value={
-            'type': fakelibvirt.VIR_DOMAIN_JOB_COMPLETED}))
+    @catch_notimplementederror
+    def test_refresh_security_group_rules(self):
+        # FIXME: Create security group and add the instance to it
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.refresh_security_group_rules(1)
+
+    @catch_notimplementederror
+    def test_refresh_security_group_members(self):
+        # FIXME: Create security group and add the instance to it
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.refresh_security_group_members(1)
+
+    @catch_notimplementederror
+    def test_refresh_instance_security_rules(self):
+        # FIXME: Create security group and add the instance to it
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.refresh_instance_security_rules(instance_ref)
+
+    @catch_notimplementederror
+    def test_refresh_provider_fw_rules(self):
+        instance_ref, network_info = self._get_running_instance()
+        self.connection.refresh_provider_fw_rules()
+
+    @catch_notimplementederror
+    def test_ensure_filtering_for_instance(self):
+        instance = test_utils.get_test_instance(obj=True)
+        network_info = test_utils.get_test_network_info()
+        self.connection.ensure_filtering_rules_for_instance(instance,
+                                                            network_info)
+
+    @catch_notimplementederror
+    def test_unfilter_instance(self):
+        instance_ref = test_utils.get_test_instance()
+        network_info = test_utils.get_test_network_info()
+        self.connection.unfilter_instance(instance_ref, network_info)
+
+    @catch_notimplementederror
     def test_live_migration(self):
         instance_ref, network_info = self._get_running_instance()
-        fake_context = context.RequestContext('fake', 'fake')
-        migration = objects.Migration(context=fake_context, id=1)
-        migrate_data = objects.LibvirtLiveMigrateData(
-            migration=migration, bdms=[], block_migration=False,
-            serial_listen_addr='127.0.0.1', serial_listen_ports=[1234])
         self.connection.live_migration(self.ctxt, instance_ref, 'otherhost',
-                                       lambda *a, **b: None,
-                                       lambda *a, **b: None,
-                                       migrate_data=migrate_data)
-
-    @catch_notimplementederror
-    def test_live_migration_force_complete(self):
-        instance_ref, network_info = self._get_running_instance()
-        self.connection.active_migrations[instance_ref.uuid] = deque()
-        self.connection.live_migration_force_complete(instance_ref)
-
-    @catch_notimplementederror
-    def test_live_migration_abort(self):
-        instance_ref, network_info = self._get_running_instance()
-        self.connection.live_migration_abort(instance_ref)
+                                       lambda *a: None, lambda *a: None)
 
     @catch_notimplementederror
     def _check_available_resource_fields(self, host_status):
@@ -645,6 +684,14 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
     def test_host_power_action_startup(self):
         self.connection.host_power_action('startup')
 
+    @catch_notimplementederror
+    def test_add_to_aggregate(self):
+        self.connection.add_to_aggregate(self.ctxt, 'aggregate', 'host')
+
+    @catch_notimplementederror
+    def test_remove_from_aggregate(self):
+        self.connection.remove_from_aggregate(self.ctxt, 'aggregate', 'host')
+
     def test_events(self):
         got_events = []
 
@@ -711,17 +758,9 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
 
         self.connection.emit_event(event1)
 
-    def test_emit_unicode_event(self):
-        """Tests that we do not fail on translated unicode events."""
-        started_event = virtevent.LifecycleEvent(
-            "cef19ce0-0ca2-11df-855d-b19fbce37686",
-            virtevent.EVENT_LIFECYCLE_STARTED)
-        callback = mock.Mock()
-        self.connection.register_event_listener(callback)
-        with mock.patch.object(started_event, 'get_name',
-                               return_value=u'\xF0\x9F\x92\xA9'):
-            self.connection.emit_event(started_event)
-        callback.assert_called_once_with(started_event)
+    def test_set_bootable(self):
+        self.assertRaises(NotImplementedError, self.connection.set_bootable,
+                          'instance', True)
 
     @catch_notimplementederror
     def test_get_instance_disk_info(self):
@@ -730,84 +769,18 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
         self.connection.get_instance_disk_info(instance_ref,
                                                block_device_info={})
 
-    @catch_notimplementederror
-    def test_get_device_name_for_instance(self):
-        instance, _ = self._get_running_instance()
-        self.connection.get_device_name_for_instance(
-            instance, [], mock.Mock(spec=objects.BlockDeviceMapping))
-
-    def test_network_binding_host_id(self):
-        # NOTE(jroll) self._get_running_instance calls spawn(), so we can't
-        # use it to test this method. Make a simple object instead; we just
-        # need instance.host.
-        instance = objects.Instance(self.ctxt, host='somehost')
-        self.assertEqual(instance.host,
-            self.connection.network_binding_host_id(self.ctxt, instance))
-
-    def test_get_allocation_ratio(self):
-        inv = {}
-        self.flags(cpu_allocation_ratio=16.1)
-        self.flags(ram_allocation_ratio=1.6)
-        self.flags(disk_allocation_ratio=1.1)
-        expected_ratios = {
-            orc.VCPU: CONF.cpu_allocation_ratio,
-            orc.MEMORY_MB: CONF.ram_allocation_ratio,
-            orc.DISK_GB: CONF.disk_allocation_ratio
-        }
-        # If conf is set, return conf
-        self.assertEqual(expected_ratios,
-                         self.connection._get_allocation_ratios(inv))
-
-        self.flags(cpu_allocation_ratio=None)
-        self.flags(ram_allocation_ratio=None)
-        self.flags(disk_allocation_ratio=None)
-        self.flags(initial_cpu_allocation_ratio=15.9)
-        self.flags(initial_ram_allocation_ratio=1.4)
-        self.flags(initial_disk_allocation_ratio=0.9)
-        expected_ratios = {
-            orc.VCPU: CONF.initial_cpu_allocation_ratio,
-            orc.MEMORY_MB: CONF.initial_ram_allocation_ratio,
-            orc.DISK_GB: CONF.initial_disk_allocation_ratio
-        }
-        # if conf is unset and inv doesn't exists, return init conf
-        self.assertEqual(expected_ratios,
-                         self.connection._get_allocation_ratios(inv))
-
-        inv = {orc.VCPU: {'allocation_ratio': 3.0},
-               orc.MEMORY_MB: {'allocation_ratio': 3.1},
-               orc.DISK_GB: {'allocation_ratio': 3.2}}
-        expected_ratios = {
-            orc.VCPU: inv[orc.VCPU]['allocation_ratio'],
-            orc.MEMORY_MB: inv[orc.MEMORY_MB]['allocation_ratio'],
-            orc.DISK_GB: inv[orc.DISK_GB]['allocation_ratio']
-        }
-        # if conf is unset and inv exists, return inv
-        self.assertEqual(expected_ratios,
-                         self.connection._get_allocation_ratios(inv))
-
 
 class AbstractDriverTestCase(_VirtDriverTestCase, test.TestCase):
     def setUp(self):
         self.driver_module = "nova.virt.driver.ComputeDriver"
         super(AbstractDriverTestCase, self).setUp()
 
-    def test_live_migration(self):
-        self.skipTest('Live migration is not implemented in the base '
-                      'virt driver.')
-
-    def test_post_claim_migrate_data(self):
-        self.assertEqual(
-            'fake-migrate-data',
-            self.connection.post_claim_migrate_data(
-                'fake-context', 'fake-instance', 'fake-migrate-data',
-                'fake-claim'))
-
 
 class FakeConnectionTestCase(_VirtDriverTestCase, test.TestCase):
     def setUp(self):
         self.driver_module = 'nova.virt.fake.FakeDriver'
+        fake.set_nodes(['myhostname'])
         super(FakeConnectionTestCase, self).setUp()
-        self.connection.init_host('myhostname')
 
     def _check_available_resource_fields(self, host_status):
         super(FakeConnectionTestCase, self)._check_available_resource_fields(
@@ -831,49 +804,14 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
         # Point _VirtDriverTestCase at the right module
         self.driver_module = 'nova.virt.libvirt.LibvirtDriver'
         super(LibvirtConnTestCase, self).setUp()
-        self.stub_out('nova.context.get_admin_context', lambda: self.ctxt)
-        # This is needed for the live migration tests which spawn off the
-        # operation for monitoring.
-        self.useFixture(nova_fixtures.SpawnIsSynchronousFixture())
-        self.useFixture(nova_fixtures.CGroupsFixture())
-        # When destroying an instance, os-vif will try to execute some commands
-        # which hang tests so let's just stub out the unplug call to os-vif
-        # since we don't care about it.
-        self.stub_out('os_vif.unplug', lambda a, kw: None)
-        self.stub_out('nova.compute.utils.get_machine_ips', lambda: [])
-        self.stub_out('nova.virt.libvirt.utils.get_disk_size',
-                      lambda *a, **k: 123456)
-        self.stub_out('nova.virt.libvirt.utils.get_disk_backing_file',
-                      lambda *a, **k: None)
-        self.stub_out('nova.privsep.path.chown', lambda *a, **k: None)
+        self.stubs.Set(self.connection,
+                       '_set_host_enabled', mock.MagicMock())
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.context.get_admin_context',
+            self._fake_admin_context))
 
-    def test_init_host_image_type_rbd_force_raw_images_true(self):
-        CONF.set_override('images_type', 'rbd', group='libvirt')
-        CONF.set_override('force_raw_images', True)
-        self.connection.init_host('myhostname')
-
-    def test_init_host_image_type_non_rbd(self):
-        CONF.set_override('images_type', 'default', group='libvirt')
-        self.connection.init_host('myhostname')
-
-    def test_init_host_raise_invalid_configuration(self):
-        CONF.set_override('images_type', 'rbd', group='libvirt')
-        CONF.set_override('force_raw_images', False)
-        self.assertRaises(exception.InvalidConfiguration,
-                          self.connection.init_host, 'myhostname')
-
-    @mock.patch('os.unlink')
-    @mock.patch('nova.virt.libvirt.utils.load_file')
-    def test_unrescue_unrescued_instance(self, mock_load_file, mock_unlink):
-        instance_ref, _ = self._get_running_instance()
-        # fake out 'unrescue.xml'
-        mock_load_file.return_value = self.connection._get_existing_domain_xml(
-            instance_ref, None,
-        )
-
-        super().test_unrescue_unrescued_instance()
-
-        self.assertIn('unrescue.xml', mock_load_file.call_args[0][0])
+    def _fake_admin_context(self, *args, **kwargs):
+        return self.ctxt
 
     def test_force_hard_reboot(self):
         self.flags(wait_soft_reboot_seconds=0, group='libvirt')
@@ -885,6 +823,7 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
                       " needed to override superclass.")
 
     def test_internal_set_host_enabled(self):
+        self.mox.UnsetStubs()
         service_mock = mock.MagicMock()
 
         # Previous status of the service: disabled: False
@@ -897,6 +836,7 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
             self.assertEqual(service_mock.disabled_reason, 'AUTO: ERROR!')
 
     def test_set_host_enabled_when_auto_disabled(self):
+        self.mox.UnsetStubs()
         service_mock = mock.MagicMock()
 
         # Previous status of the service: disabled: True, 'AUTO: ERROR'
@@ -909,6 +849,7 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
             self.assertIsNone(service_mock.disabled_reason)
 
     def test_set_host_enabled_when_manually_disabled(self):
+        self.mox.UnsetStubs()
         service_mock = mock.MagicMock()
 
         # Previous status of the service: disabled: True, 'Manually disabled'
@@ -921,6 +862,7 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
             self.assertEqual(service_mock.disabled_reason, 'Manually disabled')
 
     def test_set_host_enabled_dont_override_manually_disabled(self):
+        self.mox.UnsetStubs()
         service_mock = mock.MagicMock()
 
         # Previous status of the service: disabled: True, 'Manually disabled'
@@ -949,24 +891,3 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
         self.assertEqual(unplug_vifs_mock.call_count, 1)
         unplug_vifs_mock.assert_called_once_with(instance_ref,
                                             network_info, True)
-
-    def test_get_device_name_for_instance(self):
-        self.skipTest("Tested by the nova.tests.unit.virt.libvirt suite")
-
-    @catch_notimplementederror
-    @mock.patch('nova.utils.get_image_from_system_metadata')
-    @mock.patch("nova.virt.libvirt.host.Host.has_min_version")
-    def test_set_admin_password(self, ver, mock_image):
-        self.flags(virt_type='kvm', group='libvirt')
-        mock_image.return_value = {"properties": {
-            "hw_qemu_guest_agent": "yes"}}
-        instance, network_info = self._get_running_instance(obj=True)
-        self.connection.set_admin_password(instance, 'p4ssw0rd')
-
-    def test_get_volume_connector(self):
-        for multipath in (True, False):
-            self.flags(volume_use_multipath=multipath, group='libvirt')
-            result = super(LibvirtConnTestCase,
-                           self).test_get_volume_connector()
-            self.assertIn('multipath', result)
-            self.assertEqual(multipath, result['multipath'])
